You want to ask / know anything? just message me on Discord, Doodke#0001


Sorry for taking this name, if you need it and you really need it and have the project ready with the name David and you need this pip, speak with me I guess and maybe 
I'll delete the project so you can take it :)